==> pointpos_api-0.0.16.tar.gz: test/table_group_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for TableGroupApi
void main() {
  var instance = new TableGroupApi();

  group('tests for TableGroupApi', () {
    // Create Tablegroup
    //
    // Create Tablegroup
    //
    //Future<TableGroup> createTablegroup(String authorization, String xAPIKey, TableGroup body, { String xPin }) async 
    test('test createTablegroup', () async {
      // TODO
    });

    // Delete Tablegroup By ID
    //
    // Delete Tablegroup By ID
    //
    //Future deleteTablegroupByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteTablegroupByID', () async {
      // TODO
    });

    // Get Tablegroup List
    //
    // Get Tablegroup  List
    //
    //Future<List<TableGroup>> findTablegroup(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter }) async 
    test('test findTablegroup', () async {
      // TODO
    });

    // Get Tablegroup By ID
    //
    // Get Tablegroup By ID
    //
    //Future<TableGroup> getTablegroupByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getTablegroupByID', () async {
      // TODO
    });

    // Update Tablegroup By ID
    //
    // Update [object Object] By ID
    //
    //Future<TableGroup> updateTablegroupByID(String authorization, String xAPIKey, String id, TableGroup body, { String xPin }) async 
    test('test updateTablegroupByID', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.1.tar.gz: test/table_group_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for TableGroupApi
void main() {
  var instance = new TableGroupApi();

  group('tests for TableGroupApi', () {
    // Create Tablegroup
    //
    // Create Tablegroup
    //
    //Future<TableGroup> createTablegroup(String authorization, String xAPIKey, TableGroup body, { String xPin }) async 
    test('test createTablegroup', () async {
      // TODO
    });

    // Delete Tablegroup By ID
    //
    // Delete Tablegroup By ID
    //
    //Future deleteTablegroupByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteTablegroupByID', () async {
      // TODO
    });

    // Get Tablegroup List
    //
    // Get Tablegroup  List
    //
    //Future<List<TableGroup>> findTablegroup(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter, bool withDeleted }) async 
    test('test findTablegroup', () async {
      // TODO
    });

    // Get Tablegroup By ID
    //
    // Get Tablegroup By ID
    //
    //Future<TableGroup> getTablegroupByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getTablegroupByID', () async {
      // TODO
    });

    // Update Tablegroup By ID
    //
    // Update [object Object] By ID
    //
    //Future<TableGroup> updateTablegroupByID(String authorization, String xAPIKey, String id, TableGroup body, { String xPin }) async 
    test('test updateTablegroupByID', () async {
      // TODO
    });

  });
}
